require 'thor'
require 'mkmf'
require 'leap'

require_relative 'support/brew'
require_relative 'support/remotes'

class Leap::CLI < Thor

  desc 'setup USERNAME/PROJECT', 'Clone and install dependencies of a project'
  def setup(username_project)
    username, project_name = split_source(username_project)
    invoke :clone, [username_project]
    invoke :remotes, [project_name]
    invoke :dependencies, [project_name]
  end

  desc 'clone USERNAME/PROJECT', 'Clone project into current directory'
  def clone(username_project)
    username, project_name = split_source(username_project)
    if Dir.exists?(project_name)
      say "Project appears to already exist. Skipping clone.", :green
    else
      say "Cloning #{project_name}.", :green
      `git clone git@github.com:#{username}/#{project_name}.git`
    end
  end

  desc 'remotes', 'Sets up all relevant remotes for a project'
  def remotes(project_name = nil)
    # setup above invokes dependencies with an argument so we allow for a single
    # unused argument when called inside a project
    Remotes.new(self, Leap::CONFIG, project_name).add_specified_remotes
  end

  desc 'dependencies', 'Guided installation of dependencies for project'
  # setup above invokes dependencies with an argument so we allow for a single
  # unused argument when called inside a project
  def dependencies(project_name = nil)
    brew = Brew.new(self, Leap::CONFIG, project_name)

    brew.install unless brew.present?
    brew.install_dependencies
  end

  desc 'start', 'Starts a local server'
  def start
    remotes_file = '.leap/start'
    if File.exists?(remotes_file)
      exec(remotes_file)
    else
      say 'No start script', :red
    end
  end

  no_commands do
    def split_source(username_project)
      username_project.downcase.split("/")
    end
  end
end
