class Brew
  attr_reader :dependencies

  def initialize(thor, config, project_name)
    @dependencies = extract_dependencies(config, project_name)
    @thor = thor
  end

  def eligible?
    !RbConfig::CONFIG['host_os'].match(/darwin|mac os/).nil?
  end

  def install
    @thor.say 'Installing brew', :green
    exec('ruby -e "$(curl -fsSL https://raw.githubusercontent.com/Homebrew/install/master/install)"')
  end

  def install_dependencies
    @dependencies.each do |dependency|
      local_package = `brew list | grep #{dependency}`
      if local_package.empty?
        @thor.say "Installing #{dependency}", :green
        exec("brew install #{dependency}")
      end
    end.empty? and begin
      @thor.say "No dependencies found in leap config", :red
    end
  end

  def present?
    !(find_executable 'brew').nil?
  end

  private
  def extract_dependencies(config, project_name)
    config.fetch('dependencies') do
      if File.exists? "./#{project_name}/.leap/config"
        YAML.load_file("./#{project_name}/.leap/config")['dependencies']
      else
        []
      end
    end
  end
end
